@@ -112,7 +112,7 @@ var searchData=
   ['tds_5fgoodwrite_109',['tds_goodwrite',['../a00594.html#gae19543ec756e7ef8327d643899db9fb8',1,'tds_goodwrite(TDSSOCKET *tds, const unsigned char *buffer, size_t buflen):&#160;net.c'],['../a00594.html#gae19543ec756e7ef8327d643899db9fb8',1,'tds_goodwrite(TDSSOCKET *tds, const unsigned char *buffer, size_t buflen):&#160;net.c']]],
   ['tds_5ficonv_110',['tds_iconv',['../a00591.html#ga87db49044919f1bc84c0ff5e9ab00304',1,'tds_iconv(TDSSOCKET *tds, TDSICONV *conv, TDS_ICONV_DIRECTION io, const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft):&#160;iconv.c'],['../a00591.html#ga87db49044919f1bc84c0ff5e9ab00304',1,'tds_iconv(TDSSOCKET *tds, TDSICONV *char_conv, TDS_ICONV_DIRECTION io, const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft):&#160;iconv.c']]],
   ['tds_5ficonv_5falloc_111',['tds_iconv_alloc',['../a01502.html#a026957dbbd994b48b571a63405f427cd',1,'tds_iconv_alloc(TDSCONNECTION *conn):&#160;iconv.c'],['../a00431.html#a026957dbbd994b48b571a63405f427cd',1,'tds_iconv_alloc(TDSCONNECTION *conn):&#160;iconv.c']]],
-  ['tds_5ficonv_5ffrom_5fcollate_112',['tds_iconv_from_collate',['../a00591.html#ga9d433c15ab3738aa2a477a416330f49f',1,'tds_iconv_from_collate(TDSCONNECTION *conn, TDS_UCHAR collate[5]):&#160;iconv.c'],['../a00591.html#ga9d433c15ab3738aa2a477a416330f49f',1,'tds_iconv_from_collate(TDSCONNECTION *conn, TDS_UCHAR collate[5]):&#160;iconv.c']]],
+  ['tds_5ficonv_5ffrom_5fcollate_112',['tds_iconv_from_collate',['../a00591.html#gac4d0a96ba5e8c72bb5961c63453cc940',1,'tds_iconv_from_collate(TDSCONNECTION *conn, const TDS_UCHAR collate[5]):&#160;iconv.c'],['../a00591.html#gac4d0a96ba5e8c72bb5961c63453cc940',1,'tds_iconv_from_collate(TDSCONNECTION *conn, const TDS_UCHAR collate[5]):&#160;iconv.c']]],
   ['tds_5ficonv_5fget_5finfo_113',['tds_iconv_get_info',['../a00591.html#ga1639ccaa7e17c07457bcb37f313bc52f',1,'tds_iconv_get_info(TDSCONNECTION *conn, int canonic_client, int canonic_server):&#160;iconv.c'],['../a00591.html#ga1639ccaa7e17c07457bcb37f313bc52f',1,'tds_iconv_get_info(TDSCONNECTION *conn, int canonic_client, int canonic_server):&#160;iconv.c']]],
   ['tds_5ficonv_5finfo_5finit_114',['tds_iconv_info_init',['../a00591.html#ga3a7a7b4d6ed344127e164dd0b443d790',1,'iconv.c']]],
   ['tds_5ficonv_5finit_115',['tds_iconv_init',['../a01502.html#a30bcae80553efae075b0886bfcda1e35',1,'iconv.c']]],
